Learn R Programming

CallEshotgun (version 0.2.0)

callEshotgun: Call the e-shotgun Version 1 with Pareto front selection function in python

Description

The function checks the passed parameter and than calls the e-shotgun Python implementation and returns a matrix with the evaluated points.

Usage

callEshotgun(Xtr, Ytr, f_lb, f_ub, q = 10L, epsilon = 0.1, pf = FALSE)

Arguments

Xtr

a matrix containing the initial points

Ytr

a matrix containing the evaluation of Xtr with a given function

f_lb

a vector with the values of the lower bounds

f_ub

a vector with the values of the upper bounds

q

the amount if points that the e-shotgun should evaluate

epsilon

the epsilon value of the e-shotgun

pf

boolean that decides if pareto front is used

Value

a matrix or a vector

Details

George De Ath, Richard M. Everson, Jonathan E. Fieldsend, and Alma A. M. Rahat. 2020. e-shotgun : e-greedy Batch Bayesian Optimisation. In Genetic and Evolutionary Computation Conference (GECCO <U+2019>20), July 8<U+2013>12, 2020, Canc<U+00FA>n, Mexico. ACM, New York, NY, USA, 9 pages. https://doi.org/10.1145/3377930.3390154 https://github.com/georgedeath/eshotgun