The function checks the passed parameter and than calls the e-shotgun Python implementation and returns a matrix with the evaluated points.
callEshotgun(Xtr, Ytr, f_lb, f_ub, q = 10L, epsilon = 0.1, pf = FALSE)a matrix containing the initial points
a matrix containing the evaluation of Xtr with a given function
a vector with the values of the lower bounds
a vector with the values of the upper bounds
the amount if points that the e-shotgun should evaluate
the epsilon value of the e-shotgun
boolean that decides if pareto front is used
a matrix or a vector
George De Ath, Richard M. Everson, Jonathan E. Fieldsend, and Alma A. M. Rahat. 2020. e-shotgun : e-greedy Batch Bayesian Optimisation. In Genetic and Evolutionary Computation Conference (GECCO <U+2019>20), July 8<U+2013>12, 2020, Canc<U+00FA>n, Mexico. ACM, New York, NY, USA, 9 pages. https://doi.org/10.1145/3377930.3390154 https://github.com/georgedeath/eshotgun